@@ -8,17 +8,16 @@ Usage:
 
     class Observer(PowerManagementObserver):
         def on_power_sources_change(self, power_management):
-            print "Power sources did change."
+            print("Power sources did change.")
 
         def on_time_remaining_change(self, power_management):
-            print "Time remaining did change."
+            print("Time remaining did change.")
 
     # class Observer(object):
     #     ...
     # PowerManagementObserver.register(Observer)
 """
-__author__ = 'kulakov.ilya@gmail.com'
-__version__ = '1.2'
+__version__ = '1.4'
 
 from sys import platform
 from power.common import *
@@ -27,6 +26,8 @@ from power.common import *
 try:
     if platform.startswith('darwin'):
         from power.darwin import PowerManagement
+    elif platform.startswith('freebsd'):
+        from power.freebsd import PowerManagement
     elif platform.startswith('win32'):
         from power.win32 import PowerManagement
     elif platform.startswith('linux'):
